==> zio-aws-amplifybackend_2.13-5.17.112.1-sources.jar: zio/aws/amplifybackend/model/CreateTokenRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class CreateTokenRequest(appId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest = {
    import CreateTokenRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.CreateTokenRequest.ReadOnly =
    zio.aws.amplifybackend.model.CreateTokenRequest.wrap(buildAwsValue())
}
object CreateTokenRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.CreateTokenRequest =
      zio.aws.amplifybackend.model.CreateTokenRequest(appId)
    def appId: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest
  ) extends zio.aws.amplifybackend.model.CreateTokenRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest
  ): zio.aws.amplifybackend.model.CreateTokenRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifybackend_2.13-5.17.269.1-sources.jar: zio/aws/amplifybackend/model/CreateTokenRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class CreateTokenRequest(appId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest = {
    import CreateTokenRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest
      .builder()
      .appId(appId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.CreateTokenRequest.ReadOnly =
    zio.aws.amplifybackend.model.CreateTokenRequest.wrap(buildAwsValue())
}
object CreateTokenRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.CreateTokenRequest =
      zio.aws.amplifybackend.model.CreateTokenRequest(appId)
    def appId: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest
  ) extends zio.aws.amplifybackend.model.CreateTokenRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.CreateTokenRequest
  ): zio.aws.amplifybackend.model.CreateTokenRequest.ReadOnly = new Wrapper(
    impl
  )
}
